@@ -1,7 +1,7 @@
 /*
  *  kalocale.cpp  -  miscellaneous locale functions
  *  Program:  kalarm
- *  Copyright © 2003-2014 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2003-2018 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,12 +21,15 @@
 #include "kalarm.h"   //krazy:exclude=includes (kalarm.h must be first)
 #include "kalocale.h"
 
-#include <KLocale>
 #include "kalarm_debug.h"
 #include <QLocale>
 
-namespace KAlarm
+namespace
 {
+int firstDay     = 0;
+int firstWorkDay = 0;
+int lastWorkDay  = 0;
+uint workDays    = 0;
 
 /******************************************************************************
 * Return the first day of the week for the user's locale.
@@ -34,34 +37,54 @@ namespace KAlarm
 */
 int localeFirstDayOfWeek()
 {
-    static int firstDay = 0;
-    if (!firstDay)
+    static QLocale locale;
+    if (!firstDay || locale != QLocale())
     {
         Q_ASSERT(Qt::Monday == 1 && Qt::Sunday == 7);  // all weekday numbering assumes this
-        firstDay = QLocale().firstDayOfWeek();
+        locale = QLocale();
+        firstDay = locale.firstDayOfWeek();
+        QList<Qt::DayOfWeek> weekDays = locale.weekdays();
+        for (int i = 0; i < weekDays.size(); ++i)
+            workDays |= 1 << (weekDays.at(i) - 1);
+
+        qSort(weekDays);
+        int day = 0;
+        for (int i = 0; i < weekDays.size(); ++i)
+            if (++day < weekDays.at(i))
+            {
+                lastWorkDay = (day == 1) ? weekDays.at(weekDays.size() - 1) : day - 1;
+                firstWorkDay = weekDays.at(i);
+                break;
+            }
     }
     return firstDay;
 }
 
+}
+
+namespace KAlarm
+{
+
+/*****************************************************************************/
+int weekDay_to_localeDayInWeek(int weekDay)
+{
+    return (weekDay + 7 - localeFirstDayOfWeek()) % 7;
+}
+
+/*****************************************************************************/
+int localeDayInWeek_to_weekDay(int index)
+{
+    return (index + localeFirstDayOfWeek() - 1) % 7 + 1;
+}
+
 /******************************************************************************
 * Return the default work days in the week, as a bit mask.
-* They are determined by the start and end work days in system settings.
+* Reply = bit 1 set for Monday ... bit 0x40 for Sunday.
 */
 uint defaultWorkDays()
 {
-    KLocale* locale = KLocale::global();
-    int end = locale->workingWeekEndDay() - 1;
-    uint days = 0;
-    for (int day = locale->workingWeekStartDay() - 1;  ; )
-    {
-        days |= 1 << day;
-        if (day == end)
-            break;
-        ++day;
-        if (day >= 7)
-            day = 0;
-    }
-    return days;
+    localeFirstDayOfWeek();
+    return workDays;
 }
 
 } // namespace KAlarm
